@@ -3,12 +3,13 @@
 
 # Tolerance of machine precision
 # ------------------------------
-NP_MIN_TOL = 1e-12
+NP_MIN_TOL = 0
 
 # Bounds for optimization
 # -----------------------
 ALPHA_MIN = 0.01
 ALPHA_MAX = 100
+FSIGMA_MIN = 1
 
 # Job control
 # -----------
@@ -16,4 +17,4 @@ NRERUN = 3
 
 # Recompute p_cat frequency
 # -------------------------
-RECMP_P_CAT_FREQ = 1000
\ No newline at end of file
+RECMP_P_CAT_FREQ = 1000
